@@ -82,6 +82,15 @@ class TestParsing(unittest.TestCase):
              'foo'),
             ('from a.b import c,d', [3, 4, 5, 6]),
         )
+        self._test_import_parsing(
+            ('""" from this shall not import """',
+             'from a.b import (',
+             '    c,',
+             '    d,',
+             ')',
+             'foo'),
+            ('from a.b import c,d', [1, 2, 3, 4]),
+        )
         self._test_import_parsing(
             ('"""',
              'from this shall not import'),
@@ -93,6 +102,10 @@ class TestParsing(unittest.TestCase):
              '"""'),
             tuple(),
         )
+        self._test_import_parsing(
+            ('""" from this shall not import """'),
+            tuple(),
+        )
 
     def _test_import_string_matches(self, string, expected):
         self.assertEqual(
